==> jc-1.4.0.tar.gz: polyglot/visit/AlphaRenamer.h <==
// public class polyglot.visit.AlphaRenamer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3c16646bc612f714 polyglot_visit_AlphaRenamer
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_AlphaRenamer_H_
#define _JC_polyglot_visit_AlphaRenamer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_java_util_Stack$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_AlphaRenamer$sub_refs	_jc_polyglot_visit_AlphaRenamer$sub_refs;
typedef struct _jc_polyglot_visit_AlphaRenamer$sub_nonrefs	_jc_polyglot_visit_AlphaRenamer$sub_nonrefs;
typedef struct _jc_polyglot_visit_AlphaRenamer$refs	_jc_polyglot_visit_AlphaRenamer$refs;
typedef struct _jc_polyglot_visit_AlphaRenamer$nonrefs	_jc_polyglot_visit_AlphaRenamer$nonrefs;
typedef struct _jc_polyglot_visit_AlphaRenamer$object	_jc_polyglot_visit_AlphaRenamer$object;

typedef const struct _jc_polyglot_visit_AlphaRenamer$vmethods	_jc_polyglot_visit_AlphaRenamer$vmethods;
typedef const struct _jc_polyglot_visit_AlphaRenamer$vtable	_jc_polyglot_visit_AlphaRenamer$vtable;
typedef const struct _jc_polyglot_visit_AlphaRenamer$vtype	_jc_polyglot_visit_AlphaRenamer$vtype;

// Constructors
extern void _jc_polyglot_visit_AlphaRenamer$method$_init$0e3bea23b0bd47bf(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_AlphaRenamer$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_AlphaRenamer$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_AlphaRenamer$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_AlphaRenamer$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_AlphaRenamer$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_polyglot_visit_AlphaRenamer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_AlphaRenamer$vmethods	polyglot_visit_AlphaRenamer;
};

// Vtype
struct _jc_polyglot_visit_AlphaRenamer$vtype {
	_jc_type			type;
	_jc_polyglot_visit_AlphaRenamer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_AlphaRenamer$sub_refs {
	struct _jc_object	*nf;
	struct _jc_java_util_Stack$object	*setStack;
	struct _jc_object	*renamingMap;
	struct _jc_object	*freshVars;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_AlphaRenamer$refs {
    _jc_polyglot_visit_AlphaRenamer$sub_refs	polyglot_visit_AlphaRenamer;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_AlphaRenamer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_AlphaRenamer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_AlphaRenamer$sub_nonrefs	polyglot_visit_AlphaRenamer;
};

// Object instance structure
struct _jc_polyglot_visit_AlphaRenamer$object {
	_jc_polyglot_visit_AlphaRenamer$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_AlphaRenamer$vtype	*vtype;
	_jc_polyglot_visit_AlphaRenamer$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_AlphaRenamer$vtype _jc_polyglot_visit_AlphaRenamer$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_AlphaRenamer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_AlphaRenamer$class_object;

#endif	/* _JC_polyglot_visit_AlphaRenamer_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/AlphaRenamer.h <==
// public class polyglot.visit.AlphaRenamer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3c16646bc612f714 polyglot_visit_AlphaRenamer
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_AlphaRenamer_H_
#define _JC_polyglot_visit_AlphaRenamer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_java_util_Stack$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_AlphaRenamer$sub_refs	_jc_polyglot_visit_AlphaRenamer$sub_refs;
typedef struct _jc_polyglot_visit_AlphaRenamer$sub_nonrefs	_jc_polyglot_visit_AlphaRenamer$sub_nonrefs;
typedef struct _jc_polyglot_visit_AlphaRenamer$refs	_jc_polyglot_visit_AlphaRenamer$refs;
typedef struct _jc_polyglot_visit_AlphaRenamer$nonrefs	_jc_polyglot_visit_AlphaRenamer$nonrefs;
typedef struct _jc_polyglot_visit_AlphaRenamer$object	_jc_polyglot_visit_AlphaRenamer$object;

typedef const struct _jc_polyglot_visit_AlphaRenamer$vmethods	_jc_polyglot_visit_AlphaRenamer$vmethods;
typedef const struct _jc_polyglot_visit_AlphaRenamer$vtable	_jc_polyglot_visit_AlphaRenamer$vtable;
typedef const struct _jc_polyglot_visit_AlphaRenamer$vtype	_jc_polyglot_visit_AlphaRenamer$vtype;

// Constructors
extern void _jc_polyglot_visit_AlphaRenamer$method$_init$0e3bea23b0bd47bf(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_AlphaRenamer$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_AlphaRenamer$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_AlphaRenamer$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_AlphaRenamer$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_AlphaRenamer$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_AlphaRenamer$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_AlphaRenamer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_AlphaRenamer$vmethods	polyglot_visit_AlphaRenamer;
};

// Vtype
struct _jc_polyglot_visit_AlphaRenamer$vtype {
	_jc_type			type;
	_jc_polyglot_visit_AlphaRenamer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_AlphaRenamer$sub_refs {
	struct _jc_object	*nf;
	struct _jc_java_util_Stack$object	*setStack;
	struct _jc_object	*renamingMap;
	struct _jc_object	*freshVars;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_AlphaRenamer$refs {
    _jc_polyglot_visit_AlphaRenamer$sub_refs	polyglot_visit_AlphaRenamer;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_AlphaRenamer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_AlphaRenamer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_AlphaRenamer$sub_nonrefs	polyglot_visit_AlphaRenamer;
};

// Object instance structure
struct _jc_polyglot_visit_AlphaRenamer$object {
	_jc_polyglot_visit_AlphaRenamer$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_AlphaRenamer$vtype	*vtype;
	_jc_polyglot_visit_AlphaRenamer$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_AlphaRenamer$vtype _jc_polyglot_visit_AlphaRenamer$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_AlphaRenamer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_AlphaRenamer$class_object;

#endif	/* _JC_polyglot_visit_AlphaRenamer_H_ */
